@@ -5,11 +5,11 @@ use warnings;
 use strict;
 
 use Test::Builder;
-use File::Spec;
 use UNIVERSAL::require;
+use Test::Compile::Internal;
 
-our $VERSION = '0.18';
-my $Test = Test::Builder->new;
+our $VERSION = '0.19';
+my $Test = Test::Compile::Internal->new();
 
 sub import {
     my $self   = shift;
@@ -28,10 +28,14 @@ sub import {
 }
 
 sub pm_file_ok {
-    my $file = shift;
-    my $name = @_ ? shift : "Compile test for $file";
+    my ($file,$name,$verbose) = @_;
 
-    my $ok = _run_in_subprocess(sub{_check_syntax($file,1)});
+    $name ||= "Compile test for $file";
+
+    my $old = $Test->verbose();
+    $Test->verbose($verbose);
+    my $ok = $Test->pm_file_compiles($file);
+    $Test->verbose($old);
 
     $Test->ok($ok, $name);
     $Test->diag("$file does not compile") unless $ok;
@@ -39,9 +43,9 @@ sub pm_file_ok {
 }
 
 sub pl_file_ok {
-    my $file = shift;
-    my $name = @_ ? shift : "Compile test for $file";
-    my $verbose = shift;
+    my ($file,$name,$verbose) = @_;
+
+    $name ||= "Compile test for $file";
 
     # don't "use Devel::CheckOS" because Test::Compile is included by
     # Module::Install::StandardTests, and we don't want to have to ship
@@ -57,7 +61,10 @@ sub pl_file_ok {
         }
     }
 
-    my $ok = _run_in_subprocess(sub{_check_syntax($file,0)},$verbose);
+    my $old = $Test->verbose();
+    $Test->verbose($verbose);
+    my $ok = $Test->pl_file_compiles($file);
+    $Test->verbose($old);
 
     $Test->ok($ok, $name);
     $Test->diag("$file does not compile") unless $ok;
@@ -86,114 +93,11 @@ sub all_pl_files_ok {
 }
 
 sub all_pm_files {
-    my @queue = @_ ? @_ : _pm_starting_points();
-
-    my @pm;
-    for my $file ( _find_files(@queue) ) {
-        if (-f $file) {
-            push @pm, $file if $file =~ /\.pm$/;
-        }
-    }
-    return @pm;
+    return $Test->all_pm_files(@_);
 }
 
 sub all_pl_files {
-    my @queue = @_ ? @_ : _pl_starting_points();
-
-    my @pl;
-    for my $file ( _find_files(@queue) ) {
-        if (defined($file) && -f $file) {
-            # Only accept files with no extension or extension .pl
-            push @pl, $file if $file =~ /(?:^[^.]+$|\.pl$)/;
-        }
-    }
-    return @pl;
-}
-
-sub _run_in_subprocess {
-    my ($closure,$verbose) = @_;
-
-    my $pid = fork();
-    if ( ! defined($pid) ) {
-        return 0;
-    } elsif ( $pid ) {
-        wait();
-        return ($? ? 0 : 1);
-    } else {
-        if ( !$verbose ) {
-            open STDERR, '>', File::Spec->devnull;
-        }
-        my $rv = $closure->();
-        exit ($rv ? 0 : 1);
-    }
-}
-
-sub _check_syntax {
-    my ($file,$require) = @_;
-
-    if (-f $file) {
-        if ( $require ) {
-            my $module = $file;
-            $module =~ s!^(blib[/\\])?lib[/\\]!!;
-            $module =~ s![/\\]!::!g;
-            $module =~ s/\.pm$//;
-    
-            $module->use;
-            return ($@ ? 0 : 1);
-        } else {
-            my @perl5lib = split(':', ($ENV{PERL5LIB}||""));
-            my $taint = _is_in_taint_mode($file);
-            unshift @perl5lib, 'blib/lib';
-            system($^X, (map { "-I$_" } @perl5lib), "-c$taint", $file);
-            return ($? ? 0 : 1);
-        }
-    }
-}
-
-sub _find_files {
-    my (@queue) = @_;
-
-    for my $file (@queue) {
-        if (defined($file) && -d $file) {
-            local *DH;
-            opendir DH, $file or next;
-            my @newfiles = readdir DH;
-            closedir DH;
-            @newfiles = File::Spec->no_upwards(@newfiles);
-            @newfiles = grep { $_ ne "CVS" && $_ ne ".svn" } @newfiles;
-            for my $newfile (@newfiles) {
-                my $filename = File::Spec->catfile($file, $newfile);
-                if (-f $filename) {
-                    push @queue, $filename;
-                } else {
-                    push @queue, File::Spec->catdir($file, $newfile);
-                }
-            }
-        }
-    }
-    return @queue;
-}
-
-sub _pm_starting_points {
-    return 'blib' if -e 'blib';
-    return 'lib';
-}
-
-sub _pl_starting_points {
-    return 'script' if -e 'script';
-    return 'bin'    if -e 'bin';
-}
-
-sub _is_in_taint_mode {
-    my ($file) = @_;
-
-    open(my $f, "<", $file) or die "could not open $file";
-    my $shebang = <$f>;
-    my $taint = "";
-    if ($shebang =~ /^#![\/\w]+\s+\-w?([tT])/) {
-        $taint = $1;
-    }
-    return $taint;
+    return $Test->all_pl_files(@_);
 }
 
 1;
