@@ -8,26 +8,22 @@ use File::Spec;
 use UNIVERSAL::require;
 use Test::Builder;
 
-our $VERSION = 'v0.24.0';
+our $VERSION = '0.19';
 
 =head1 NAME
 
-Test::Compile::Internal - Test whether your perl files compile.
+Test::Compile::Internal - Internal workings for Test::Compile.
 
 =head1 SYNOPSIS
 
     use Test::Compile::Internal;
-    my $test = Test::Compile::Internal->new();
-    $test->all_files_ok();
-    $test->done_testing();
+    my $tci = Test::Compile::Internal->new();
+    $tci->all_files_ok();
+    $tci->done_testing();
 
 =head1 DESCRIPTION
 
-C<Test::Compile::Internal> is an object oriented tool for testing whether your
-perl files compile.
-
-It is primarily to provide the inner workings of C<Test::Compile>, but it can
-also be used directly to test a CPAN distribution.
+Don't use this module directly, it is BETA software, and subject to change
 
 =head1 METHODS
 
@@ -48,14 +44,10 @@ sub new {
     return $self;
 }
 
-=item C<all_files_ok(@dirs)>
+=item C<all_files_ok([@dirs])>
 
 Checks all the perl files it can find for compilation errors.
 
-If C<@dirs> is defined then it is taken as an array of directories to 
-be searched for perl files, otherwise it searches some default locatioons
-- see L</all_pm_files()> and L</all_pl_files()>. 
-
 =cut
 sub all_files_ok {
     my ($self,@dirs) = @_;
@@ -74,9 +66,9 @@ sub all_files_ok {
 }
 
 
-=item C<verbose($verbose)>
+=item C<verbose([$verbose])>
 
-An accessor to get/set the verbose flag.  If C<verbose> is set, you can get some 
+An accessor to get/set the verbose flag.  If verbose is set, you can get some 
 extra diagnostics when compilation fails.
 
 Verbose is set off by default.
@@ -92,10 +84,10 @@ sub verbose {
     return $self->{verbose};
 }
 
-=item C<all_pm_files(@dirs)>
+=item C<all_pm_files([@dirs])>
 
 Returns a list of all the perl module files - that is any files ending in F<.pm>
-in C<@dirs> and in directories below. If C<@dirs> is undefined, it
+in I<@dirs> and in directories below. If @dirs is not passed, it
 searches F<blib> if F<blib> exists, or else F<lib>.
 
 Skips any files in C<CVS> or C<.svn> directories.
@@ -118,11 +110,11 @@ sub all_pm_files {
     return @pm;
 }
 
-=item C<all_pl_files(@dirs)>
+=item C<all_pl_files([@dirs])>
 
 Returns a list of all the perl script files - that is, any files ending in F<.pl>
-or files with no extension in C<@dirs> and in directories below. If
-C<@dirs> is undefined, it searches F<script> if F<script> exists, or else
+or files with no extension in I<@dirs> and in directories below. If
+@dirs is not passed, it searches F<script> if F<script> exists, or else
 F<bin> if F<bin> exists.
 
 Skips any files in C<CVS> or C<.svn> directories.
@@ -149,54 +141,29 @@ sub all_pl_files {
 
 =item C<pl_file_compiles($file)>
 
-Returns true if C<$file> compiles as a perl script.
+Returns true if $file compiles as a perl script.
 
 =cut
 
 sub pl_file_compiles {
     my ($self,$file) = @_;
-    return $self->_run_closure(
-        sub{
-            if ( -f $file ) {
-                my @inc = ('blib/lib', @INC);
-                my $taint = $self->_is_in_taint_mode($file);
-                system($^X, (map { "-I$_" } @inc), "-c$taint", $file);
-                return ($? ? 0 : 1);
-            }
-        }
-    );
+    my $ok = $self->_run_in_subprocess(sub{$self->_check_syntax($file,0)});
 }
 
 =item C<pm_file_compiles($file)>
 
-Returns true if C<$file> compiles as a perl module.
+Returns true if $file compiles as a perl module.
 
 =back
 =cut
 
 sub pm_file_compiles {
     my ($self,$file) = @_;
-
-    return $self->_run_closure(
-        sub{
-            if ( -f $file ) {
-                my $module = $file;
-                $module =~ s!^(blib[/\\])?lib[/\\]!!;
-                $module =~ s![/\\]!::!g;
-                $module =~ s/\.pm$//;
-    
-                $module->use;
-                return ($@ ? 0 : 1);
-            }
-        }
-    );
+    my $ok = $self->_run_in_subprocess(sub{$self->_check_syntax($file,1)});
 }
 
 =head1 TEST METHODS
 
-C<Test::Compile::Internal> encapsulates a C<Test::Builder> object, and provides
-access to some of its methods.
-
 =over 4
 
 =item C<done_testing()>
@@ -211,8 +178,7 @@ sub done_testing {
 
 =item C<ok($test,$name)>
 
-Your basic test. Pass if C<$test> is true, fail if C<$test> is false. Just
-like C<Test::Simple>'s C<ok()>.
+Your basic test. Pass if $test is true, fail if $test is false. Just like Test::Simple's ok().
 
 =cut
 sub ok {
@@ -232,8 +198,7 @@ sub plan {
 
 =item C<exported_to($caller)>
 
-Tells C<Test::Builder> what package you exported your functions to.  I am
-not sure why you would want to do that, or whether it would do you any good.
+Tells Test::Builder what package you exported your functions to.  I am not sure why you would want to do that, or whether it would do you any good.
 
 =cut
 
@@ -244,11 +209,9 @@ sub exported_to {
 
 =item C<diag(@msgs)>
 
-Prints out the given C<@msgs>. Like print, arguments are simply appended
-together.
+Prints out the given @msgs. Like print, arguments are simply appended together.
 
-Output will be indented and marked with a # so as not to interfere with
-test output. A newline will be put on the end if there isn't one already.
+Output will be indented and marked with a # so as not to interfere with test output. A newline will be put on the end if there isn't one already.
 
 We encourage using this rather than calling print directly.
 
@@ -261,7 +224,7 @@ sub diag {
 
 =item C<skip($why)>
 
-Skips the current test, reporting C<$why>.
+Skips the current test, reporting $why.
 
 =cut
 
@@ -272,7 +235,7 @@ sub skip {
 
 =item C<skip_all($reason)>
 
-Skips all the tests, using the given C<$reason>. Exits immediately with 0.
+Skips all the tests, using the given $reason. Exits immediately with 0.
 
 =back
 =cut
@@ -282,7 +245,7 @@ sub skip_all {
     $self->{test}->skip_all(@args);
 }
 
-sub _run_closure {
+sub _run_in_subprocess {
     my ($self,$closure) = @_;
 
     my $pid = fork();
@@ -291,15 +254,35 @@ sub _run_closure {
     } elsif ( $pid ) {
         wait();
         return ($? ? 0 : 1);
+    } else {
+        if ( ! $self->verbose() ) {
+            open STDERR, '>', File::Spec->devnull;
+        }
+        my $rv = $closure->();
+        exit ($rv ? 0 : 1);
     }
+}
 
-    if ( ! $self->verbose() ) {
-        open STDERR, '>', File::Spec->devnull;
+sub _check_syntax {
+    my ($self,$file,$require) = @_;
+
+    if (-f $file) {
+        if ( $require ) {
+            my $module = $file;
+            $module =~ s!^(blib[/\\])?lib[/\\]!!;
+            $module =~ s![/\\]!::!g;
+            $module =~ s/\.pm$//;
+    
+            $module->use;
+            return ($@ ? 0 : 1);
+        } else {
+            my @perl5lib = split(':', ($ENV{PERL5LIB}||""));
+            my $taint = $self->_is_in_taint_mode($file);
+            unshift @perl5lib, 'blib/lib';
+            system($^X, (map { "-I$_" } @perl5lib), "-c$taint", $file);
+            return ($? ? 0 : 1);
+        }
     }
-
-    my $rv = $closure->();
-
-    exit ($rv ? 0 : 1);
 }
 
 sub _find_files {
@@ -342,13 +325,15 @@ sub _is_in_taint_mode {
     open(my $f, "<", $file) or die "could not open $file";
     my $shebang = <$f>;
     my $taint = "";
-    if ($shebang =~ /^#!\s*[\/\w]+\s+-\w*([tT])/) {
+    if ($shebang =~ /^#![\/\w]+\s+\-w?([tT])/) {
         $taint = $1;
     }
     return $taint;
 }
 
 1;
+__END__
+
 
 =head1 AUTHORS
 
@@ -358,14 +343,14 @@ Evan Giles, C<< <egiles@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2013 by the authors.
+Copyright 2007-2012 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Test::Strict> proveds functions to ensure your perl files comnpile, with
-the added bonus that it will check you have used strict in all your files.
+L<Test::LoadAllModules> just handles modules, not script files, but has more
+fine-grained control.
 
 =cut
